@@ -1,8 +1,6 @@
-import os
 from pathlib import Path
 
 import pkg_resources
-from grpc_tools import protoc
 
 
 def install_proto():
