@@ -18,4 +18,4 @@ class ProcessorService(processor_pb2_grpc.ProcessorServicer):
                 jsonString=json.dumps(item), streamEnd=False
             )
 
-        yield processor_pb2.FlowResponse(jsonString={}, streamEnd=True)
+        yield processor_pb2.FlowResponse(jsonString="", streamEnd=True)
